#include "spawn.h"

#include "..\algorithms.h"

void botInfo::gotHelp(Player *p, Command *c)
{
	// List commands

	if (!*c->final)
	{
		switch (p->access)
		{
		case OP_Duke:
		case OP_Baron:
		case OP_King:
		case OP_Emperor:
		case OP_RockStar:
		case OP_Q:
		case OP_God:
		case OP_Owner:
			{	// Owner-level commands
			}
		case OP_SysOp:
			{	// SysOp-level commands
			}
		case OP_SuperModerator:
			{	// SuperModerator-level commands
			}
		case OP_Moderator:
			{	// Moderator-level commands
			}
		case OP_Limited:
			{	// Limited-level commands
				if (state == ELIM_Playing)
					sendPrivate(p, "Ext: !about !status !rank !force !stop");
				else
					sendPrivate(p, "Ext: !about !status !rank !start");
			}
			break;
		case OP_Player:
			{	// Player-level commands
				sendPrivate(p, "Ext: !about !status !rank");
			}
		}

		return;
	}

	// Specific command help

	switch (p->access)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
			if (c->checkParam("owner") || c->checkParam("all"))
			{
			}
		}
	case OP_SysOp:
		{	// SysOp-level commands
			if (c->checkParam("sop") || c->checkParam("all"))
			{
			}
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
			if (c->checkParam("smod") || c->checkParam("all"))
			{
			}
		}
	case OP_Moderator:
		{	// Moderator-level commands
			if (c->checkParam("mod") || c->checkParam("all"))
			{
				if (state == ELIM_Playing)
					sendPrivate(p, "Ext: !about !status !rank !force !stop");
				else
					sendPrivate(p, "Ext: !about !status !rank !start");
			}
		}
	case OP_Limited:
		{	// Limited-level commands
			if (c->checkParam("force"))
			{
				sendPrivate(p, "!force <choice> (force a decision)");
			}
			else if (c->checkParam("start"))
			{
				sendPrivate(p, "!start (begin a game of elimination)");
			}
			else if (c->checkParam("stop"))
			{
				sendPrivate(p, "!stop (end a game in progress)");
			}
		}
	case OP_Player:
		{	// Player-level commands
			if (c->checkParam("about"))
			{
				sendPrivate(p, "!about (query me about my function)");
			}
			else if (c->checkParam("status"))
			{
				sendPrivate(p, "!status (what's up doc?)");
			}
			else if (c->checkParam("rank"))
			{
				sendPrivate(p, "!rank [player name] (display player rank)");
			}
		}
	}
}

void botInfo::gotCommand(Player *p, Command *c)
{
	if (!p) return;
	if (!c) return;

	switch (p->access)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
		}
	case OP_SysOp:
		{	// SysOp-level commands
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
			if (c->check("version"))
			{
				sendPrivate(p, "[name:elim.dll] [maker:Catid@pacbell.net] [build:2]");
			}
		}
	case OP_Moderator:
		{	// Moderator-level commands
		}
	case OP_Limited:
		{	// Limited-level commands
			if (state != ELIM_NotPlaying)
			{
				if (c->check("stop"))
				{
					sendPublic(SND_BassBeep, "*arena Elimination cancelled[forced].");

					state = ELIM_NotPlaying;
				}
				else if (state == ELIM_Voting)
				{
					if (c->check("force"))
					{
						if (isNumeric(c->final))
						{
							deaths = getInteger(c->final, 10);

							if (deaths < 0) deaths = 1;
							if (deaths > 999) deaths = 999;

							String s;
							s += "*arena Playing to ";
							s += deaths;
							s += "[forced]. Game will begin in 10 seconds...";
							sendPublic(SND_TrebleBeep, s);

							state = ELIM_GetReady;
							countdown[0] = 10;
						}
					}
				}
			}
			else
			{
				if (c->check("start"))
				{
					if (!sendGreet())
						sendPrivate(p, "Game restarting. I have already sent a *zone message in the last 2 minutes");

					state = ELIM_Announcing;
					countdown[0] = 1;
				}
			}
		}
	case OP_Player:
		{	// Player-level commands
			if (c->check("about"))
			{
				sendPrivate(p, "I host elimination games.");
			}
			else if (c->check("status"))
			{
				sendPrivate(p, getStatus());
			}
			else if (c->check("rank"))
			{
				sendPrivate(p, "Yeah, you're pretty rank alright.");
			}
		}
	}
}

void botInfo::gotRemoteHelp(char *p, Command *c, Operator_Level l)
{
	// List commands

	if (!*c->final)
	{
		switch (l)
		{
		case OP_Duke:
		case OP_Baron:
		case OP_King:
		case OP_Emperor:
		case OP_RockStar:
		case OP_Q:
		case OP_God:
		case OP_Owner:
			{	// Owner-level commands
			}
		case OP_SysOp:
			{	// SysOp-level commands
			}
		case OP_SuperModerator:
			{	// SuperModerator-level commands
			}
		case OP_Moderator:
			{	// Moderator-level commands
			}
		case OP_Limited:
			{	// Limited-level commands
			}
		case OP_Player:
			{	// Player-level commands
			}
		}

		return;
	}

	// Specific command help

	switch (l)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
		}
	case OP_SysOp:
		{	// SysOp-level commands
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
		}
	case OP_Moderator:
		{	// Moderator-level commands
		}
	case OP_Limited:
		{	// Limited-level commands
		}
	case OP_Player:
		{	// Player-level commands
		}
	}
}

void botInfo::gotRemote(char *p, Command *c, Operator_Level l)
{
	if (!c) return;

	switch (l)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
		}
	case OP_SysOp:
		{	// SysOp-level commands
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
		}
	case OP_Moderator:
		{	// Moderator-level commands
		}
	case OP_Limited:
		{	// Limited-level commands
		}
	case OP_Player:
		{	// Player-level commands
		}
	}
}
